@@ -1,7 +1,12 @@
 import inspect
 import typing
 from .base_response import BaseResponse
-from vkbottle_types.objects import BaseBoolInt, OrdersAmount, OrdersOrder, OrdersSubscription
+from vkbottle_types.objects import (
+    BaseBoolInt,
+    OrdersAmount,
+    OrdersOrder,
+    OrdersSubscription,
+)
 
 
 class CancelSubscriptionResponse(BaseResponse):
