@@ -1,7 +1,11 @@
 import inspect
 import typing
 from .base_response import BaseResponse
-from vkbottle_types.objects import PagesWikipage, PagesWikipageFull, PagesWikipageHistory
+from vkbottle_types.objects import (
+    PagesWikipage,
+    PagesWikipageFull,
+    PagesWikipageHistory,
+)
 
 
 class GetHistoryResponse(BaseResponse):
